//LabPlot : PstoEditDialog.h

#ifndef PSTOEDITDIALOG_H
#define PSTOEDITDIALOG_H

#include <qfont.h>
#include <qcheckbox.h>
#include "MainWin.h"
#include "Dialog.h"

class PstoEditDialog: public Dialog
{
	Q_OBJECT
public:
	PstoEditDialog(MainWin *mw, QString fn=i18n("out.pdf"), int f=4, int s=5, double sc=1.0,
		double r=0.0, const char *name=0);
public slots:
	void updateFilename(int index);
	void selectFile();
	void Apply() { apply_clicked(); accept(); }
	void apply_clicked();
private:
	KComboBox *format, *pagesize;
	KLineEdit *filele, *scalele, *rotle;
};

#endif //PSTOEDITDIALOG_H
